@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
@@ -16,7 +16,12 @@ import aws_cdk.aws_sqs._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-s3-notifications", "1.45.0", __name__[0:-6], "aws-s3-notifications@1.45.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-s3-notifications",
+    "1.139.0",
+    __name__[0:-6],
+    "aws-s3-notifications@1.139.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
